summaryrefslogtreecommitdiffstats
path: root/chrome/common/pref_names.cc
diff options
context:
space:
mode:
authormirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-21 01:00:34 +0000
committermirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-21 01:00:34 +0000
commit0ef69c756f644654452dd9ce94ab95f14b6c998c (patch)
treecca6d5a31f07791216185e0a49cd5d271891a2c4 /chrome/common/pref_names.cc
parent2e3e1908a954a3e23ddc08ff7f2023b0d3b92a21 (diff)
downloadchromium_src-0ef69c756f644654452dd9ce94ab95f14b6c998c.zip
chromium_src-0ef69c756f644654452dd9ce94ab95f14b6c998c.tar.gz
chromium_src-0ef69c756f644654452dd9ce94ab95f14b6c998c.tar.bz2
Add the ability to change NTP logos using a command from the web resource server.
BUG=none TEST=none Review URL: http://codereview.chromium.org/3418020 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@60001 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/pref_names.cc')
-rw-r--r--chrome/common/pref_names.cc21
1 files changed, 12 insertions, 9 deletions
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index 84a8cc85..78ca687 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -874,27 +874,30 @@ const char kNTPMostVisitedURLsBlacklist[] = "ntp.most_visited_blacklist";
// Page.
const char kNTPMostVisitedPinnedURLs[] = "ntp.pinned_urls";
-// Data downloaded from resource pages (JSON, RSS) to be displayed in the
-// recommendations portion of the NTP.
-const char kNTPTipsCache[] = "ntp.tips_cache";
+// Data downloaded from resource pages (JSON, RSS) to be used to dynamically
+// deliver data for the new tab page.
+const char kNTPWebResourceCache[] = "ntp.web_resource_cache";
-// Last time of update of tips_cache.
-const char kNTPTipsCacheUpdate[] = "ntp.tips_cache_update";
+// Last time of update of web_resource_cache.
+const char kNTPWebResourceCacheUpdate[] = "ntp.web_resource_cache_update";
-// Last server used to fill tips_cache.
-const char kNTPTipsServer[] = "ntp.tips_server";
+// Last server used to fill web_resource_cache.
+const char kNTPWebResourceServer[] = "ntp.web_resource_server";
// Which sections should be visible on the new tab page
// 1 - Show the most visited sites in a grid
// 2 - Show the most visited sites as a list
// 4 - Show the recent section
-// 8 - Show tips
-// 16 - show sync status
+// 8 - (Show tips -- DEPRECATED)
+// 16 - Show sync status
const char kNTPShownSections[] = "ntp.shown_sections";
// This pref is used for migrating the prefs for the NTP
const char kNTPPrefVersion[] = "ntp.pref_version";
+// Used if the NTP should show a custom logo rather than the standard one.
+const char kNTPCustomLogo[] = "ntp.custom_logo";
+
// A boolean specifying whether dev tools window should be opened docked.
const char kDevToolsOpenDocked[] = "devtools.open_docked";